@@ -1,10 +1,10 @@
 package cli
 
 import (
-	"fmt"
 	"os"
-	"time"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/config"
+	"github.com/jandedobbeleer/oh-my-posh/src/dsc"
 	"github.com/spf13/cobra"
 )
 
@@ -16,10 +16,7 @@ var configCmd = &cobra.Command{
 
 You can export, migrate or edit the config (via the editor specified in the environment variable "EDITOR").`,
 	ValidArgs: []string{
-		"export",
-		"migrate",
 		"edit",
-		"get",
 	},
 	Args: NoArgsOrOneValidArg,
 	Run: func(cmd *cobra.Command, args []string) {
@@ -31,9 +28,6 @@ You can export, migrate or edit the config (via the editor specified in the envi
 		switch args[0] {
 		case "edit":
 			exitcode = editFileWithEditor(os.Getenv("POSH_THEME"))
-		case "get":
-			// only here for backwards compatibility
-			fmt.Print(time.Now().UnixNano() / 1000000)
 		default:
 			_ = cmd.Help()
 		}
@@ -41,5 +35,6 @@ You can export, migrate or edit the config (via the editor specified in the envi
 }
 
 func init() {
+	configCmd.AddCommand(dsc.Command(config.DSC()))
 	RootCmd.AddCommand(configCmd)
 }
