@@ -5,6 +5,7 @@ import (
 	"strings"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/cli/font"
+	"github.com/jandedobbeleer/oh-my-posh/src/dsc"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
@@ -53,11 +54,23 @@ This command is used to install fonts and configure the font in your terminal.
 					zipFolder += "/"
 				}
 
-				if err := font.Run(fontName, env.Cache(), env.Root(), zipFolder); err != nil {
+				fontName, err := font.Run(fontName, env.Cache(), zipFolder)
+				if err != nil {
 					log.Error(err)
 					exitcode = 70
+					return
 				}
 
+				if env.Root() {
+					// do not update the DSC cache if we are running as root
+					return
+				}
+
+				fontDSC := font.DSC()
+				fontDSC.Load(env.Cache())
+				fontDSC.Add(fontName)
+				fontDSC.Save()
+
 				return
 			case "configure":
 				fmt.Println("not implemented")
@@ -70,5 +83,6 @@ This command is used to install fonts and configure the font in your terminal.
 
 func init() {
 	fontCmd.Flags().StringVar(&zipFolder, "zip-folder", "", "the folder inside the zip file to install fonts from")
+	fontCmd.AddCommand(dsc.Command(font.DSC()))
 	RootCmd.AddCommand(fontCmd)
 }
