@@ -5,7 +5,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/google/uuid"
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/color"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
@@ -16,7 +15,7 @@ import (
 
 // getCmd represents the get command
 var getCmd = &cobra.Command{
-	Use:   "get [shell|millis|accent|toggles|width|uuid]",
+	Use:   "get [shell|millis|accent|toggles|width]",
 	Short: "Get a value from oh-my-posh",
 	Long: `Get a value from oh-my-posh.
 
@@ -26,15 +25,13 @@ This command is used to get the value of the following variables:
 - millis
 - accent
 - toggles
-- width
-- uuid`,
+- width`,
 	ValidArgs: []string{
 		"millis",
 		"shell",
 		"accent",
 		"toggles",
 		"width",
-		"uuid",
 	},
 	Args: NoArgsOrOneValidArg,
 	Run: func(cmd *cobra.Command, args []string) {
@@ -68,15 +65,18 @@ This command is used to get the value of the following variables:
 			accent := color2.RGB(rgb.R, rgb.G, rgb.B)
 			fmt.Print("#" + accent.Hex())
 		case "toggles":
-			togglesCache, _ := env.Session().Get(cache.TOGGLECACHE)
 			var toggles []string
+
+			togglesCache, _ := env.Session().Get(cache.TOGGLECACHE)
 			if len(togglesCache) != 0 {
 				toggles = strings.Split(togglesCache, ",")
 			}
+
 			if len(toggles) == 0 {
 				fmt.Println("No segments are toggled off")
 				return
 			}
+
 			fmt.Println("Toggled off segments:")
 			for _, toggle := range toggles {
 				fmt.Println("- " + toggle)
@@ -87,9 +87,8 @@ This command is used to get the value of the following variables:
 				fmt.Println("error getting terminal width:", err.Error())
 				return
 			}
+
 			fmt.Print(width)
-		case "uuid":
-			fmt.Print(uuid.NewString())
 		default:
 			_ = cmd.Help()
 		}
