@@ -64,8 +64,6 @@ const (
 	FetchStatus properties.Property = "fetch_status"
 	// IgnoreStatus allows to ignore certain repo's for status information
 	IgnoreStatus properties.Property = "ignore_status"
-	// FetchStashCount fetches the stash count
-	FetchStashCount properties.Property = "fetch_stash_count"
 	// FetchWorktreeCount fetches the worktree count
 	FetchWorktreeCount properties.Property = "fetch_worktree_count"
 	// FetchUpstreamIcon fetches the upstream icon
@@ -171,8 +169,9 @@ func (g *Git) Template() string {
 }
 
 func (g *Git) Enabled() bool {
-	// g.command = GITCOMMAND
 	g.User = &User{}
+	g.Working = &GitStatus{}
+	g.Staging = &GitStatus{}
 
 	if !g.shouldDisplay() {
 		return false
@@ -185,9 +184,6 @@ func (g *Git) Enabled() bool {
 
 	g.RepoName = g.repoName()
 
-	g.Working = &GitStatus{}
-	g.Staging = &GitStatus{}
-
 	if g.IsBare {
 		g.getBareRepoInfo()
 		return true
@@ -199,7 +195,7 @@ func (g *Git) Enabled() bool {
 	}
 
 	displayStatus := g.props.GetBool(FetchStatus, false)
-	if g.shouldIgnoreStatus() {
+	if displayStatus && g.shouldIgnoreStatus() {
 		displayStatus = false
 	}
 
@@ -208,7 +204,7 @@ func (g *Git) Enabled() bool {
 		g.setGitHEADContext()
 		g.setBranchStatus()
 	} else {
-		g.setPrettyHEADName()
+		g.setHEADName()
 	}
 
 	if g.props.GetBool(FetchUpstreamIcon, false) {
@@ -318,14 +314,14 @@ func (g *Git) Kraken() string {
 		root = strings.Split(root, "\n")[0]
 	}
 
-	if len(g.RawUpstreamURL) == 0 {
-		if len(g.Upstream) == 0 {
+	if g.RawUpstreamURL == "" {
+		if g.Upstream == "" {
 			g.Upstream = "origin"
 		}
 		g.RawUpstreamURL = g.getRemoteURL()
 	}
 
-	if len(g.Hash) == 0 {
+	if g.Hash == "" {
 		g.Hash = g.getGitCommandOutput("rev-parse", "HEAD")
 	}
 
@@ -337,22 +333,16 @@ func (g *Git) LatestTag() string {
 }
 
 func (g *Git) shouldDisplay() bool {
-	if !g.hasCommand(GITCOMMAND) {
+	gitdir, err := g.env.HasParentFilePath(".git", true)
+	if err != nil {
 		return false
 	}
 
 	if g.props.GetBool(FetchBareInfo, false) {
-		g.repoRootDir = g.env.Pwd()
-		bare := g.getGitCommandOutput("rev-parse", "--is-bare-repository")
-		if bare == trueStr {
-			g.IsBare = true
-			g.mainSCMDir = g.repoRootDir
-			return true
-		}
+		g.IsBare = g.isBareRepo(gitdir)
 	}
 
-	gitdir, err := g.env.HasParentFilePath(".git", true)
-	if err != nil {
+	if !g.hasCommand(GITCOMMAND) {
 		return false
 	}
 
@@ -383,20 +373,41 @@ func (g *Git) setUser() {
 	g.User.Email = g.getGitCommandOutput("config", "user.email")
 }
 
-func (g *Git) getBareRepoInfo() {
-	file, err := g.env.HasParentFilePath(".git", true)
+func (g *Git) isBareRepo(gitDir *runtime.FileInfo) bool {
+	defer log.Trace(time.Now())
 
-	if err == nil && file.IsDir {
-		g.mainSCMDir = file.Path
-	}
-
-	// we can have a pointer to a bare repo
-	if err == nil && !file.IsDir {
-		content := g.fileContent(file.ParentFolder, ".git")
+	if gitDir.IsDir {
+		g.mainSCMDir = gitDir.Path
+	} else {
+		content := g.fileContent(gitDir.ParentFolder, ".git")
 		dir := strings.TrimPrefix(content, "gitdir: ")
-		g.mainSCMDir = filepath.Join(file.ParentFolder, dir)
+		g.mainSCMDir = filepath.Join(gitDir.ParentFolder, dir)
 	}
 
+	configData := g.fileContent(g.mainSCMDir, "config")
+	if configData == "" {
+		log.Debug("Git config file not found, not a bare repo")
+		return false
+	}
+
+	cfg, err := ini.Load([]byte(configData))
+	if err != nil {
+		log.Error(err)
+		return false
+	}
+
+	coreSection := cfg.Section("core")
+	if coreSection == nil {
+		log.Debug("Git core section not found, not a bare repo")
+		return false
+	}
+
+	bare := coreSection.Key("bare").String()
+
+	return bare == trueStr
+}
+
+func (g *Git) getBareRepoInfo() {
 	head := g.fileContent(g.mainSCMDir, "HEAD")
 	branchIcon := g.props.GetString(BranchIcon, "\uE0A0")
 	g.Ref = strings.Replace(head, "ref: refs/heads/", "", 1)
@@ -569,7 +580,7 @@ func (g *Git) cleanUpstreamURL(url string) string {
 
 func (g *Git) getUpstreamIcon() string {
 	g.RawUpstreamURL = g.getRemoteURL()
-	if len(g.RawUpstreamURL) == 0 {
+	if g.RawUpstreamURL == "" {
 		return ""
 	}
 
@@ -689,11 +700,16 @@ func (g *Git) setGitStatus() {
 }
 
 func (g *Git) getGitCommandOutput(args ...string) string {
+	if g.command == "" {
+		return ""
+	}
+
 	args = append([]string{"-C", g.repoRootDir, "--no-optional-locks", "-c", "core.quotepath=false", "-c", "color.status=false"}, args...)
 	val, err := g.env.RunCommand(g.command, args...)
 	if err != nil {
 		return ""
 	}
+
 	return val
 }
 
@@ -701,7 +717,7 @@ func (g *Git) setGitHEADContext() {
 	branchIcon := g.props.GetString(BranchIcon, "\uE0A0")
 	if g.Ref == DETACHED {
 		g.Detached = true
-		g.setPrettyHEADName()
+		g.setHEADName()
 	} else {
 		head := g.formatBranch(g.Ref)
 		g.HEAD = fmt.Sprintf("%s%s", branchIcon, head)
@@ -854,9 +870,9 @@ func (g *Git) getGitRefFileSymbolicName(refFile string) string {
 	return g.getGitCommandOutput("name-rev", "--name-only", "--exclude=tags/*", ref)
 }
 
-func (g *Git) setPrettyHEADName() {
+func (g *Git) setHEADName() {
 	// we didn't fetch status, fallback to parsing the HEAD file
-	if len(g.ShortHash) == 0 {
+	if g.ShortHash == "" {
 		HEADRef := g.fileContent(g.mainSCMDir, "HEAD")
 		g.Detached = !strings.HasPrefix(HEADRef, "ref:")
 		if after, ok := strings.CutPrefix(HEADRef, BRANCHPREFIX); ok {
@@ -882,7 +898,7 @@ func (g *Git) setPrettyHEADName() {
 	}
 
 	// fallback to commit
-	if len(g.ShortHash) == 0 {
+	if g.ShortHash == "" {
 		g.HEAD = g.props.GetString(NoCommitsIcon, "\uF594 ")
 		return
 	}
@@ -914,7 +930,7 @@ func (g *Git) WorktreeCount() int {
 
 func (g *Git) getRemoteURL() string {
 	upstream := regex.ReplaceAllString("/.*", g.Upstream, "")
-	if len(upstream) == 0 {
+	if upstream == "" {
 		upstream = "origin"
 	}
 
@@ -974,7 +990,7 @@ func (g *Git) getSwitchMode(property properties.Property, gitSwitch, mode string
 	if val := repoModes[g.repoRootDir]; len(val) != 0 {
 		mode = val
 	}
-	if len(mode) == 0 {
+	if mode == "" {
 		return ""
 	}
 	return fmt.Sprintf("%s%s", gitSwitch, mode)
