@@ -2,12 +2,15 @@ package segments
 
 import (
 	"fmt"
+	"path/filepath"
 	"sort"
 	"strings"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
+	"github.com/jandedobbeleer/oh-my-posh/src/text"
 )
 
 const (
@@ -46,7 +49,7 @@ func (s *ScmStatus) Changed() bool {
 }
 
 func (s *ScmStatus) String() string {
-	var status strings.Builder
+	status := text.NewBuilder()
 
 	if s.Formats == nil {
 		s.Formats = make(map[string]string)
@@ -99,6 +102,27 @@ const (
 	BranchTemplate properties.Property = "branch_template"
 )
 
+func (s *scm) RelativeDir() string {
+	if s.repoRootDir == "" {
+		return ""
+	}
+
+	pwd := s.env.Pwd()
+	log.Debug("repo root dir:", s.repoRootDir, "pwd:", pwd)
+
+	rel, err := filepath.Rel(s.repoRootDir, pwd)
+	if err != nil {
+		log.Error(err)
+	}
+
+	if rel == "." || rel == "" {
+		log.Debug("repo root dir is the same as the current working directory, returning empty string")
+		return ""
+	}
+
+	return rel
+}
+
 func (s *scm) formatBranch(branch string) string {
 	mappedBranches := s.props.GetKeyValueMap(MappedBranches, make(map[string]string))
 
@@ -134,24 +158,19 @@ func (s *scm) formatBranch(branch string) string {
 	}
 
 	branchTemplate := s.props.GetString(BranchTemplate, "")
-	if len(branchTemplate) == 0 {
+	if branchTemplate == "" {
 		return branch
 	}
 
-	tmpl := &template.Text{
-		Template: branchTemplate,
-		Context:  struct{ Branch string }{Branch: branch},
-	}
-
-	text, err := tmpl.Render()
+	txt, err := template.Render(branchTemplate, struct{ Branch string }{Branch: branch})
 	if err != nil {
 		return branch
 	}
 
-	return text
+	return txt
 }
 
-func (s *scm) FileContents(folder, file string) string {
+func (s *scm) fileContent(folder, file string) string {
 	return strings.Trim(s.env.FileContent(folder+"/"+file), " \r\n")
 }
 
